==> haskell-text-short-0.1.2-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-FP7YjXhqVkbEWJ0LpXWwZn
key: text-short-0.1.2-FP7YjXhqVkbEWJ0LpXWwZn
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: d7ee1dd63c8b364602cc5959bc949e07
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.4.3/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-FP7YjXhqVkbEWJ0LpXWwZn
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg deepseq-1.4.3.0
    text-1.2.3.0 binary-0.8.5.1 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-short-0.1.2-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-1GUJKpYUrhCHCIJVJXzjfN
key: text-short-0.1.2-1GUJKpYUrhCHCIJVJXzjfN
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: 9a90376f740edeeb27fddef390ea99da
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.4.3/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-1GUJKpYUrhCHCIJVJXzjfN
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg deepseq-1.4.3.0
    text-1.2.3.0 binary-0.8.5.1 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
